/* This file was generated by syncqt. */
#ifndef QT_QTTOOLS_VERSION_H
#define QT_QTTOOLS_VERSION_H

#define QTTOOLS_VERSION_STR "6.7.2"

#define QTTOOLS_VERSION 0x060702

#endif // QT_QTTOOLS_VERSION_H
