

set -ex



test -e $PREFIX/bin/linguist6
test -e $PREFIX/bin/designer6
test -e $PREFIX/bin/pixeltool6
test -e $PREFIX/bin/assistant6
test -e $PREFIX/bin/qdistancefieldgenerator6
test -e $PREFIX/bin/qtplugininfo6
test -e $PREFIX/bin/qdbus6
test -e $PREFIX/bin/qdbusviewer6
test -e $PREFIX/bin/qtdiag6
exit 0
